@@ -477,7 +477,7 @@ loop0                                     0"""
 
         self.linuxscsi._execute = fake_execute
         info = self.linuxscsi.find_multipath_device('/dev/sdd')
-        LOG.error("Device info: %s" % info)
+        LOG.error("Device info: %s", info)
 
         self.assertEqual('36005076303ffc48e0000000000000101', info['id'])
         self.assertEqual('36005076303ffc48e0000000000000101', info['name'])
@@ -508,7 +508,7 @@ loop0                                     0"""
         size = 'junk'
         mock_execute.return_value = (size, None)
         ret_size = self.linuxscsi.get_device_size('/dev/fake')
-        self.assertEqual(None, ret_size)
+        self.assertIsNone(ret_size)
 
         size_bad = '1024\n'
         size_good = 1024
@@ -657,3 +657,11 @@ loop0                                     0"""
         result = self.linuxscsi.process_lun_id(lun_id)
         expected = 13
         self.assertEqual(expected, result)
+
+    @mock.patch('os_brick.privileged.rootwrap')
+    def test_is_multipath_running_default_executor(self, mock_rootwrap):
+        self.assertTrue(
+            linuxscsi.LinuxSCSI.is_multipath_running(
+                False, None, mock_rootwrap.execute))
+        mock_rootwrap.execute.assert_called_once_with(
+            'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
